@@ -559,6 +559,13 @@ func TestPowershell_GenerateScript(t *testing.T) {
 		`  Remove-Item -Force -Recurse ".git/hooks"` + eol +
 		`}`
 
+	cleanUidGidFiles := `` +
+		`if( (Get-Command -Name Remove-Item2 -Module NTFSSecurity -ErrorAction SilentlyContinue) -and (Test-Path ".gitlab-build-uid-gid" -PathType Leaf) ) {` + eol +
+		`  Remove-Item2 -Force ".gitlab-build-uid-gid"` + eol +
+		`} elseif(Test-Path ".gitlab-build-uid-gid") {` + eol +
+		`  Remove-Item -Force ".gitlab-build-uid-gid"` + eol +
+		`}`
+
 	if eol == "\n" {
 		shebang = "#!/usr/bin/env pwsh\n"
 	} else {
@@ -604,7 +611,8 @@ func TestPowershell_GenerateScript(t *testing.T) {
 					rmGitLabEnvScript +
 					eol + eol +
 					cleanGitFiles +
-					eol +
+					cleanUidGidFiles +
+					eol + eol + eol +
 					"}" + eol + eol
 			},
 		},
@@ -621,6 +629,8 @@ func TestPowershell_GenerateScript(t *testing.T) {
 					eol + eol +
 					cleanGitFiles +
 					cleanGitConfigs +
+					eol + eol +
+					cleanUidGidFiles +
 					eol + eol + eol +
 					"}" + eol + eol
 			},
@@ -985,40 +995,17 @@ func TestPowershellEntrypointCommand(t *testing.T) {
 // TestGitCredHelperDifferentJobOS asserts that the git cred helper script is rendered differently across OSes and shell
 // types.
 func TestGitCredHelperDifferentJobOS(t *testing.T) {
-	doubleQuotedBlobs := []string{"password=${env:CI_JOB_TOKEN}`n", "get"}
-	expectedInnerDoubleQuotes := map[string]map[string]string{
-		"": {
-			SNPowershell: ternary(runtime.GOOS == "windows", `\"`, `"`),
-			SNPwsh:       `"`,
-		},
-		"linux": {
-			SNPowershell: `"`,
-			SNPwsh:       `"`,
-		},
-		"windows": {
-			SNPowershell: `\"`,
-			SNPwsh:       `"`,
-		},
+	doubleQuotedBlobs := []string{"password=${CI_JOB_TOKEN}", "get"}
+	expectedInnerDoubleQuotes := map[string]string{
+		SNPowershell: `\"`,
+		SNPwsh:       `"`,
 	}
 
-	for jobOS, shellQuotes := range expectedInnerDoubleQuotes {
-		t.Run(jobOS, func(t *testing.T) {
-			for shellName, expectedDoubleQuote := range shellQuotes {
-				t.Run(shellName, func(t *testing.T) {
-					shell := common.GetShell(shellName)
-					helper := shell.GetGitCredHelperCommand(jobOS)
-					for _, s := range doubleQuotedBlobs {
-						assert.Contains(t, helper, expectedDoubleQuote+s+expectedDoubleQuote)
-					}
-				})
-			}
-		})
+	for shellName, expectedDoubleQuote := range expectedInnerDoubleQuotes {
+		shell := common.GetShell(shellName)
+		helper := shell.GetGitCredHelperCommand()
+		for _, s := range doubleQuotedBlobs {
+			assert.Contains(t, helper, expectedDoubleQuote+s+expectedDoubleQuote)
+		}
 	}
 }
-
-func ternary[T any](condition bool, whenTrue T, whenFalse T) T {
-	if condition {
-		return whenTrue
-	}
-	return whenFalse
-}
